@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11669 2019-07-31 11:16:05Z Trista $
+# $Id: __init__.py 11861 2020-01-14 12:00:19Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Trista $ (last)
-# $Date: 2019-07-31 19:16:05 +0800 (週三, 31 七月 2019) $
-# $Revision: 11669 $
+# $Author: Lavender $ (last)
+# $Date: 2020-01-14 21:00:19 +0900 (週二, 14 一月 2020) $
+# $Revision: 11861 $
 
 import os
 import sys
@@ -88,7 +88,6 @@ def attachSettings(settingsDict):
     # Django plugins.
     ADDING_INSTALLED_APPS = [
         'djangocms_history',
-        'djangocms_forms',
         'djangocms_file',
         'djangocms_picture',
         'Zephyrus.boilerplate',
@@ -104,6 +103,11 @@ def attachSettings(settingsDict):
         'django_gravatar',
         'captcha',
     ]
+    
+    if DJANGO_VERSION <= 20000: # 2.0.0
+       ADDING_INSTALLED_APPS += [
+            'djangocms_forms',
+       ]
 
     if ZEPHYRUS_BLOG_ENABLE:
         ADDING_INSTALLED_APPS += [
