@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: build_products.py 11502 2019-05-01 05:37:40Z Lavender $
+# $Id: build_products.py 11848 2020-01-07 15:08:27Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-01 13:37:40 +0800 (週三, 01 五月 2019) $
-# $Revision: 11502 $
+# $Date: 2020-01-08 00:08:27 +0900 (週三, 08 一月 2020) $
+# $Revision: 11848 $
 
 import os
 import sys
@@ -39,7 +39,7 @@ def createEnv(version):
 
     # windows
     if 'Windows' in platform.system(): 
-        pythonPath =  os.path.join(envPath, 'Scripts', 'python.exe')
+        pythonPath =  os.path.join(envPath, 'python.exe')
         cwdPath =  os.path.join(envPath, 'Scripts')
         scriptPath = os.path.join(PROJECT_VIRTUALENV_DIR, 'CreateEnv.bat')
     else:
@@ -90,7 +90,7 @@ class Command(BaseCommand):
             help="build all template for TemplateShop.")
         parser.add_argument(
             '-c', '--cmsVersion', 
-            type=str, default="3.6.0",
+            type=str, default="3.7.0",
             help="CMS version for products.")
         
 
@@ -104,11 +104,11 @@ class Command(BaseCommand):
         machineLog = createLogger('ProductMachine', "MachineError.log")
 
         # create env
-        envPath = self.createEnv(version)
+        envPath, pythonPath = self.createEnv(version)
         
         # create project
         machineName = hashlib.md5(
-            startPath + str(datetime.datetime.now())).hexdigest()
+            (startPath + str(datetime.datetime.now())).encode()).hexdigest()
         machinePath = self.createProject(machineName, version)
         templateDir = self.unzipTemplates(startPath, machineName, templateShop)
         
@@ -123,15 +123,20 @@ class Command(BaseCommand):
             # create env
             env['VIRTUAL_ENV'] = envPath[0]
             envPython = envPath[1].replace("\\", "/")
+            
+            if 'Windows' in platform.system(): 
+                activateCommand = 'call activate "%s"' % (envPath,)
+            else:
+                activateCommand = 'source activate "%s"' % (envPath,)
 
             if not templateShop:
-                cmd = "%s manage.py build_templates \"%s\" \"%s\" -o" % (
-                        envPython, templateDir, dstPath)
+                cmd = "python manage.py build_templates \"%s\" \"%s\" -o" % (
+                        templateDir, dstPath)
             else:
-                cmd = "%s manage.py build_templates \"%s\" \"%s\"" % (
-                        envPython, templateDir, dstPath)
+                cmd = "python manage.py build_templates \"%s\" \"%s\"" % (
+                        templateDir, dstPath)
 
-            run(cmd, env=env, shell=True)
+            run("%s && %s" % (activateCommand, cmd), env=env, shell=True)
             with open(os.path.join(machinePath, 'BuildTemplates.log')) as log:
                 content = log.read()
             if content:
