@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11237 2018-10-04 12:45:49Z Lavender $
+# $Id: models.py 11861 2020-01-14 12:00:19Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-10-04 20:45:49 +0800 (週四, 04 十月 2018) $
-# $Revision: 11237 $
+# $Date: 2020-01-14 21:00:19 +0900 (週二, 14 一月 2020) $
+# $Revision: 11861 $
 
 from django.db import models
 from django.utils.translation import ugettext as _
@@ -24,7 +24,7 @@ from oscar.core.loading import get_model
 
 from Zephyrus.cms_oscar import settings
 
-Category = get_model('catalogue', 'category')
+Category = get_model('catalogue', 'Category')
 ConditionalOffer = get_model('offer', 'ConditionalOffer')
 
 OR = 1
