@@ -2,7 +2,7 @@ from django.contrib import admin
 
 # Register your models here.
 
-from .models import InstagramPhoto
+from Zephyrus.instagram.models import InstagramPhoto
 
 
 class InstagramPhotoAdmin(admin.ModelAdmin):
