@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11686 2019-08-21 04:00:34Z Lavender $
+# $Id: models.py 11720 2019-09-23 06:12:17Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-08-21 13:00:34 +0900 (週三, 21 八月 2019) $
-# $Revision: 11686 $
+# $Date: 2019-09-23 15:12:17 +0900 (週一, 23 九月 2019) $
+# $Revision: 11720 $
 
 from django.db import models
 from jsonfield import JSONField
@@ -28,3 +28,6 @@ class Email(models.Model):
         
     def __unicode__(self):
         return u"%s From: %s (%s)" % (self.email, self.fromUrl, self.date)
+        
+    def __str__(self):
+        return "%s From: %s (%s)" % (self.email, self.fromUrl, self.date)
