@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: LandingSocial.py 10323 2017-09-26 10:41:04Z Lavender $
+# $Id: LandingSocial.py 11861 2020-01-14 12:00:19Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,14 +12,20 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-09-26 18:41:04 +0800 (週二, 26 九月 2017) $
-# $Revision: 10323 $
+# $Date: 2020-01-14 21:00:19 +0900 (週二, 14 一月 2020) $
+# $Revision: 11861 $
 
 from django import template
 from django.utils.safestring import mark_safe
-from django.core.urlresolvers import reverse
 from djangocms_forms.utils import int_to_hashid
 
+from Iuppiter.DjangoUtil import DJANGO_VERSION
+
+if DJANGO_VERSION <= 20000: # 2.0.0:
+    from django.core.urlresolvers import reverse
+else:
+    from django.urls import reverse
+
 register = template.Library()
 
 @register.simple_tag
