@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 11785 2019-12-01 11:40:04Z Andy $
+# $Id: views.py 11791 2019-12-10 12:41:41Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Andy $
-# $Date: 2019-12-01 19:40:04 +0800 (週日, 01 十二月 2019) $
-# $Revision: 11785 $
+# $Author: Lavender $
+# $Date: 2019-12-10 21:41:41 +0900 (週二, 10 十二月 2019) $
+# $Revision: 11791 $
 
 import datetime
 import logging
@@ -54,7 +54,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
         landingForm = get_object_or_404(FormDefinition, pk=formId)
         form = FormBuilder(landingForm, data=request.POST, files=request.FILES)
         if not form.is_valid():
-            return
+            return redirect(fromUrl)
             
         order = landingForm.fields.all()
         excludedFieldTypes = ['MathCaptcha', 'ReCaptcha']
@@ -122,7 +122,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
                 send_mail(
                     title,
                     message,
-                    settings.EMAIL_HOST_USER,
+                    settings.DEFAULT_FROM_EMAIL,
                     settings.ZEPHYRUS_LANDING_SEND_TO,
                     fail_silently=False
                 )
@@ -136,7 +136,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
                 send_mail(
                     title,
                     message,
-                    settings.EMAIL_HOST_USER,
+                    settings.DEFAULT_FROM_EMAIL,
                     landingForm.email_to.split(','),
                     fail_silently=False
                 )
@@ -152,7 +152,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
                 send_mail(
                     title.render(),
                     mail.render(replaceStr),
-                    settings.EMAIL_HOST_USER,
+                    settings.DEFAULT_FROM_EMAIL,
                     [email.email,],
                     fail_silently=False
                 )
@@ -162,7 +162,7 @@ def sendAndRedirect(request, email, fromUrl, redirectTo, formId=None):
                 send_mail(
                     title,
                     mail.render(Context(replaceStr)),
-                    settings.EMAIL_HOST_USER,
+                    settings.DEFAULT_FROM_EMAIL,
                     [email.email,],
                     fail_silently=False
                 )
