@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: middleware.py 11720 2019-09-23 06:12:17Z Lavender $
+# $Id: middleware.py 11869 2020-01-14 14:23:13Z Lavender $
 #
 # Copyright (c) 2019 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,13 +12,14 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-09-23 14:12:17 +0800 (週一, 23 九月 2019) $
-# $Revision: 11720 $
+# $Date: 2020-01-14 23:23:13 +0900 (週二, 14 一月 2020) $
+# $Revision: 11869 $
 
 import re
 
 from django.conf import settings
 from django.http import HttpResponse
+from django.utils.deprecation import MiddlewareMixin
 
 from Iuppiter.DjangoUtil import DJANGO_VERSION
 from Zephyrus.statistics.models import URL
@@ -38,7 +39,7 @@ else:
         re.compile(r'admin/'),
     ]
     
-class BasetatisticsMiddleware(object):
+class StatisticsMiddleware(MiddlewareMixin):
     def process_request(self, request):
         # match
         path2 = request.path[1:] # 去掉網址最前面的 /
@@ -68,19 +69,3 @@ class BasetatisticsMiddleware(object):
  
     def process_response(self, request, response):
         return response
-
-if DJANGO_VERSION >= 11100:
-    class StatisticsMiddleware(BasetatisticsMiddleware):
-        def __init__(self, get_response):
-            self.get_response = get_response
-            
-        def __call__(self, request):
-            return self.get_response(request)
-
-        def process_exception(self, request, exception): 
-            return HttpResponse(str(exception))
-            
-        
-else:
-    class StatisticsMiddleware(object):
-        pass
\ No newline at end of file
